==> haskell-quickcheck-2.14.3-70.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 QuickCheck
version:              2.14.3
visibility:           public
id:                   QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
key:                  QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
license:              BSD-3-Clause
copyright:
    2000-2019 Koen Claessen, 2006-2008 Björn Bringert, 2009-2019 Nick Smallbone

maintainer:           Nick Smallbone <nick@smallbone.se>
author:               Koen Claessen <koen@chalmers.se>
homepage:             https://github.com/nick8325/quickcheck
synopsis:             Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    Specifications are expressed in Haskell, using combinators provided by
    QuickCheck. QuickCheck provides combinators to define properties, observe the
    distribution of test data, and define test data generators.

    Most of QuickCheck'\''s functionality is exported by the main "Test.QuickCheck"
    module. The main exception is the monadic property testing library in
    "Test.QuickCheck.Monadic".

    If you are new to QuickCheck, you can try looking at the following resources:

    * The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>.
    It'\''s a bit out-of-date in some details and doesn'\''t cover newer QuickCheck features,
    but is still full of good advice.
    * <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>,
    a detailed tutorial written by a user of QuickCheck.

    The <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>
    companion package provides instances for types in Haskell Platform packages
    at the cost of additional dependencies.

category:             Testing
abi:                  edcb4a348aa74c339cb6b883797c4c32
exposed:              True
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Features
    Test.QuickCheck.Function Test.QuickCheck.Gen
    Test.QuickCheck.Gen.Unsafe Test.QuickCheck.Modifiers
    Test.QuickCheck.Monadic Test.QuickCheck.Poly
    Test.QuickCheck.Property Test.QuickCheck.Random
    Test.QuickCheck.State Test.QuickCheck.Test Test.QuickCheck.Text

import-dirs:          /usr/lib/ghc-9.2.8/site-local/QuickCheck-2.14.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/QuickCheck-2.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.2.8/QuickCheck-2.14.3
hs-libraries:         HSQuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    splitmix-0.1.0.5-HVESxjxwSfmC4HE369voNE template-haskell-2.18.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html:         /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-2.14.3-149.5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck
version:              2.14.3
visibility:           public
id:                   QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
key:                  QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
license:              BSD-3-Clause
copyright:
    2000-2019 Koen Claessen, 2006-2008 Björn Bringert, 2009-2019 Nick Smallbone

maintainer:           Nick Smallbone <nick@smallbone.se>
author:               Koen Claessen <koen@chalmers.se>
homepage:             https://github.com/nick8325/quickcheck
synopsis:             Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    Specifications are expressed in Haskell, using combinators provided by
    QuickCheck. QuickCheck provides combinators to define properties, observe the
    distribution of test data, and define test data generators.

    Most of QuickCheck'\''s functionality is exported by the main "Test.QuickCheck"
    module. The main exception is the monadic property testing library in
    "Test.QuickCheck.Monadic".

    If you are new to QuickCheck, you can try looking at the following resources:

    * The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>.
    It'\''s a bit out-of-date in some details and doesn'\''t cover newer QuickCheck features,
    but is still full of good advice.
    * <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>,
    a detailed tutorial written by a user of QuickCheck.

    The <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>
    companion package provides instances for types in Haskell Platform packages
    at the cost of additional dependencies.

category:             Testing
abi:                  f92d934cd5b030671a07438c4be5d402
exposed:              True
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Features
    Test.QuickCheck.Function Test.QuickCheck.Gen
    Test.QuickCheck.Gen.Unsafe Test.QuickCheck.Modifiers
    Test.QuickCheck.Monadic Test.QuickCheck.Poly
    Test.QuickCheck.Property Test.QuickCheck.Random
    Test.QuickCheck.State Test.QuickCheck.Test Test.QuickCheck.Text

import-dirs:          /usr/lib/ghc-9.4.8/site-local/QuickCheck-2.14.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/QuickCheck-2.14.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/QuickCheck-2.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.4.8/QuickCheck-2.14.3
hs-libraries:         HSQuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj
    splitmix-0.1.0.5-VySLVrq0y0LKk6Q7y7Rys template-haskell-2.19.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html:         /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
